summaryrefslogtreecommitdiffstats
path: root/test/Win32
diff options
context:
space:
mode:
authorSteven Knight <knight@baldmt.com>2009-04-16 15:41:23 (GMT)
committerSteven Knight <knight@baldmt.com>2009-04-16 15:41:23 (GMT)
commit9b8ccfaa89dc6ac713b12a326780586143f1ad31 (patch)
treee14b18b52361062a1e9db85fd85d85b8147a489c /test/Win32
parent0c80feb11aed6cb608112e53e29c93956bb0f767 (diff)
downloadSCons-9b8ccfaa89dc6ac713b12a326780586143f1ad31.zip
SCons-9b8ccfaa89dc6ac713b12a326780586143f1ad31.tar.gz
SCons-9b8ccfaa89dc6ac713b12a326780586143f1ad31.tar.bz2
Win32 fixes: update error message, accomodate re match.
Diffstat (limited to 'test/Win32')
-rw-r--r--test/Win32/bad-drive.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/Win32/bad-drive.py b/test/Win32/bad-drive.py
index 513f7fa..200ae02 100644
--- a/test/Win32/bad-drive.py
+++ b/test/Win32/bad-drive.py
@@ -86,13 +86,13 @@ test.run(arguments = 'aaa.out')
test.fail_test(test.read('aaa.out') != "aaa.in\n")
# This next test used to provide a slightly different error message:
# "scons: *** Do not know how to make target `%snot_mentioned'. Stop.\n"
# Right now, it doesn't seem important enough to track down exactly
# why this changed and fix it, but we'll preserve it here in case it
# becomes an issue or some refactoring restores the old behavior.
test.run(arguments = bad_drive + 'not_mentioned',
- stderr = "scons: *** Do not know how to make target `%snot_mentioned'. Stop.\n" % (bad_drive),
+ stderr = "scons: *** Do not know how to make File target `%snot_mentioned'. Stop.\n" % (bad_drive),
status = 2)
expect = "scons: *** [%sno_target_1] No drive `%s' for target `%sno_target_1'.\n" % (bad_drive, bad_drive, bad_drive)
@@ -86,13 +86,13 @@ test.run(arguments = 'aaa.out')
test.fail_test(test.read('aaa.out') != "aaa.in\n")
# This next test used to provide a slightly different error message:
-# "scons: *** Do not know how to make target `%snot_mentioned'. Stop.\n"
+# "scons: *** Do not know how to make File target `%snot_mentioned'. Stop.\n"
# Right now, it doesn't seem important enough to track down exactly
# why this changed and fix it, but we'll preserve it here in case it